rest\_framework\_simplejwt package
==================================

Submodules
----------

rest\_framework\_simplejwt.authentication module
------------------------------------------------

.. automodule:: ninja_jwt.authentication
    :members:
    :undoc-members:
    :show-inheritance:

rest\_framework\_simplejwt.models module
----------------------------------------

.. automodule:: ninja_jwt.models
    :members:
    :undoc-members:
    :show-inheritance:

rest\_framework\_simplejwt.serializers module
---------------------------------------------

.. automodule:: ninja_jwt.serializers
    :members:
    :undoc-members:
    :show-inheritance:

rest\_framework\_simplejwt.tokens module
----------------------------------------

.. automodule:: ninja_jwt.tokens
    :members:
    :undoc-members:
    :show-inheritance:

rest\_framework\_simplejwt.utils module
---------------------------------------

.. automodule:: ninja_jwt.utils
    :members:
    :undoc-members:
    :show-inheritance:

rest\_framework\_simplejwt.views module
---------------------------------------

.. automodule:: ninja_jwt.views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ninja_jwt
    :members:
    :undoc-members:
    :show-inheritance:
